@@ -73,10 +73,17 @@
 #include <QApplication>
 #include <QStandardPaths>
 #include <QTimer>
+#include <QToolBar>
 
 KOWindowList *ActionManager::mWindowList = nullptr;
 
-ActionManager::ActionManager(KXMLGUIClient *client, CalendarView *widget, QObject *parent, KOrg::MainWindow *mainWindow, bool isPart, QMenuBar *menuBar)
+ActionManager::ActionManager(KXMLGUIClient *client,
+                             CalendarView *widget,
+                             QObject *parent,
+                             KOrg::MainWindow *mainWindow,
+                             bool isPart,
+                             QMenuBar *menuBar,
+                             QToolBar *toolBar)
     : QObject(parent)
 {
     new KOrgCalendarAdaptor(this);
@@ -88,6 +95,7 @@ ActionManager::ActionManager(KXMLGUIClient *client, CalendarView *widget, QObjec
     mIsPart = isPart;
     mMainWindow = mainWindow;
     mMenuBar = menuBar;
+    mToolBar = toolBar;
 }
 
 ActionManager::~ActionManager()
@@ -109,11 +117,11 @@ ActionManager::~ActionManager()
 void ActionManager::toggleMenubar(bool dontShowWarning)
 {
     if (mMenuBar) {
-        if (mHideMenuBarAction->isChecked()) {
+        if (mShowMenuBarAction->isChecked()) {
             mMenuBar->show();
         } else {
-            if (!dontShowWarning) {
-                const QString accel = mHideMenuBarAction->shortcut().toString();
+            if (!dontShowWarning && (!mToolBar->isVisible() || !mToolBar->actions().contains(mHamburgerMenu))) {
+                const QString accel = mShowMenuBarAction->shortcut().toString();
                 KMessageBox::information(mCalendarView,
                                          i18n("<qt>This will hide the menu bar completely."
                                               " You can show it again by typing %1.</qt>",
@@ -123,7 +131,7 @@ void ActionManager::toggleMenubar(bool dontShowWarning)
             }
             mMenuBar->hide();
         }
-        KOPrefs::instance()->setShowMenuBar(mHideMenuBarAction->isChecked());
+        KOPrefs::instance()->setShowMenuBar(mShowMenuBarAction->isChecked());
     }
 }
 
@@ -263,11 +271,11 @@ void ActionManager::initActions()
     /** Archive Action **/
     // TODO: Icon
     action = new QAction(i18n("Archive O&ld Incidences..."), this);
-    action->setStatusTip(i18nc("@info:status", "Archive incidences to file"));
-    action->setToolTip(i18nc("@info:tooltip", "Archive old incidences to an iCalendar file"));
+    action->setStatusTip(i18nc("@info:status", "Archive events and to-dos to a file"));
+    action->setToolTip(i18nc("@info:tooltip", "Archive old events and to-dos to an iCalendar file"));
     action->setWhatsThis(i18nc("@info:whatsthis",
                                "This menu entry opens a dialog that allows you to select old events and to-dos "
-                               "that you can archive into an iCalendar file.  The archived incidences will "
+                               "that you can archive into an iCalendar file.  They will "
                                "be removed from your existing calendar collection."));
     mACollection->addAction(QStringLiteral("file_archive"), action);
     connect(action, &QAction::triggered, this, &ActionManager::file_archive);
@@ -665,8 +673,8 @@ void ActionManager::initActions()
     }
 
     //~~~~~~~~~~~~~~~~~~~~~~~~~~~~ SIDEBAR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-    mHideMenuBarAction = KStandardAction::showMenubar(this, &ActionManager::toggleMenubar, mACollection);
-    mHideMenuBarAction->setChecked(KOPrefs::instance()->showMenuBar());
+    mShowMenuBarAction = KStandardAction::showMenubar(this, &ActionManager::toggleMenubar, mACollection);
+    mShowMenuBarAction->setChecked(KOPrefs::instance()->showMenuBar());
     toggleMenubar(true);
 
     action = new QAction(i18n("Configure &Date && Time..."), this);
@@ -690,6 +698,30 @@ void ActionManager::initActions()
         KStandardAction::preferences(mCalendarView, &CalendarView::edit_options, mACollection);
         KStandardAction::keyBindings(this, &ActionManager::keyBindings, mACollection);
     }
+    if (mMenuBar) {
+        mHamburgerMenu = KStandardAction::hamburgerMenu(nullptr, nullptr, mACollection);
+        mHamburgerMenu->setShowMenuBarAction(mShowMenuBarAction);
+        mHamburgerMenu->setMenuBar(mMenuBar);
+        connect(mHamburgerMenu, &KHamburgerMenu::aboutToShowMenu, this, [this]() {
+            updateHamburgerMenu();
+            // Immediately disconnect. We only need to run this once, but on demand.
+            // NOTE: The nullptr at the end disconnects all connections between
+            // q and mHamburgerMenu's aboutToShowMenu signal.
+            disconnect(mHamburgerMenu, &KHamburgerMenu::aboutToShowMenu, this, nullptr);
+        });
+    }
+}
+
+void ActionManager::updateHamburgerMenu()
+{
+    QMenu *menu = new QMenu;
+
+    menu->addAction(mACollection->action(QStringLiteral("conf_datetime")));
+    menu->addSeparator();
+    menu->addAction(mACollection->action(QLatin1String(KStandardAction::name(KStandardAction::Print))));
+    menu->addSeparator();
+    menu->addAction(mACollection->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))));
+    mHamburgerMenu->setMenu(menu);
 }
 
 void ActionManager::setItems(const QStringList &lst, int idx)
@@ -1308,7 +1340,7 @@ void ActionManager::keyBindings()
         dlg.addCollection(mMainWindow->getActionCollection());
     }
 
-    for (KOrg::Part *part : qAsConst(mParts)) {
+    for (KOrg::Part *part : std::as_const(mParts)) {
         if (part) {
             dlg.addCollection(part->actionCollection(), part->shortInfo());
         }
