@@ -8,8 +8,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_SEARCHDIALOG_H
-#define KORG_SEARCHDIALOG_H
+#pragma once
 
 #include <AkonadiCore/Item>
 
@@ -72,4 +71,3 @@ private:
     QPushButton *mUser1Button = nullptr;
 };
 
-#endif
