@@ -8,8 +8,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_KODAYMATRIX_H
-#define KORG_KODAYMATRIX_H
+#pragma once
 
 #include <Akonadi/Calendar/ETMCalendar>
 
@@ -324,4 +323,3 @@ private:
     bool mHighlightJournals = false;
 };
 
-#endif
