@@ -14,14 +14,12 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
+#include <KPluginFactory>
 
-KCModule *create_todosummary(QWidget *parent, const char *)
-{
-    return new KCMTodoSummary(parent);
-}
+K_PLUGIN_CLASS_WITH_JSON(KCMTodoSummary, "kcmtodosummary.json")
 
-KCMTodoSummary::KCMTodoSummary(QWidget *parent)
-    : KCModule(parent)
+KCMTodoSummary::KCMTodoSummary(QWidget *parent, const QVariantList &args)
+    : KCModule(parent, args)
 {
     setupUi(this);
 
@@ -138,16 +136,18 @@ void KCMTodoSummary::defaults()
 
 const KAboutData *KCMTodoSummary::aboutData() const
 {
-    KAboutData *about = new KAboutData(QStringLiteral("kcmtodosummary"),
-                                       i18n("Pending To-dos Configuration Dialog"),
-                                       QString(),
-                                       QString(),
-                                       KAboutLicense::GPL,
-                                       i18n("Copyright © 2003–2004 Tobias Koenig\n"
-                                            "Copyright © 2005–2010 Allen Winter"));
+    auto about = new KAboutData(QStringLiteral("kcmtodosummary"),
+                                i18n("Pending To-dos Configuration Dialog"),
+                                QString(),
+                                QString(),
+                                KAboutLicense::GPL,
+                                i18n("Copyright © 2003–2004 Tobias Koenig\n"
+                                     "Copyright © 2005–2010 Allen Winter"));
 
     about->addAuthor(i18n("Tobias Koenig"), QString(), QStringLiteral("tokoe@kde.org"));
     about->addAuthor(i18n("Allen Winter"), QString(), QStringLiteral("winter@kde.org"));
 
     return about;
 }
+
+#include "kcmtodosummary.moc"
