@@ -127,7 +127,7 @@ void KOViewManager::writeSettings(KConfig *config)
     }
 
     // write out custom view configuration
-    for (KOrg::BaseView *const view : qAsConst(mViews)) {
+    for (KOrg::BaseView *const view : std::as_const(mViews)) {
         KConfigGroup group = KSharedConfig::openConfig()->group(view->identifier());
         view->saveConfig(group);
     }
@@ -232,11 +232,7 @@ void KOViewManager::updateView()
 void KOViewManager::updateView(QDate start, QDate end, QDate preferredMonth)
 {
     if (mCurrentView && mCurrentView != mTodoView) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        mCurrentView->setDateRange(QDateTime(start), QDateTime(end), preferredMonth);
-#else
         mCurrentView->setDateRange(QDateTime(start.startOfDay()), QDateTime(end.startOfDay()), preferredMonth);
-#endif
     } else if (mTodoView) {
         mTodoView->updateView();
     }
@@ -593,7 +589,7 @@ void KOViewManager::currentAgendaViewTabChanged(int index)
 
 void KOViewManager::addChange(EventViews::EventView::Change change)
 {
-    for (BaseView *view : qAsConst(mViews)) {
+    for (BaseView *view : std::as_const(mViews)) {
         if (view) {
             view->setChanges(view->changes() | change);
         }
