@@ -6,8 +6,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef KORG_VIEWS_KOJOURNALVIEW_H
-#define KORG_VIEWS_KOJOURNALVIEW_H
+#pragma once
 
 #include "baseview.h"
 #include <KCalendarCore/Incidence> // for KCalendarCore::DateList typedef
@@ -60,4 +59,3 @@ private:
     EventViews::JournalView *const mJournalView;
 };
 
-#endif
